/*
 * img.h
 * Dan Wallach <dwallach@cs.princeton.edu>
 * 26 September 1995
 *
 * Stuff to convert from Tk images to a more sane data structure and back
 *
 * $Id: img.h,v 1.4 1995/09/30 21:10:22 dwallach Exp $
 */
 
#ifndef __TKENHANCE_IMG_H__
#define __TKENHANCE_IMG_H__

#include <tcl.h>
#include <tk.h>

/***************************************************************************
 * Image processing data structures
 ***************************************************************************/

typedef struct {
    unsigned char r, g, b, a;
} ImgPixel;

typedef struct {
  float r, g, b, a;
} FloatImgPixel;

#define PIXEL_LUMINANCE(p) (((p).r * 76 + (p).g * 150 + (p).b * 29) / 256)
#define EPSILON 0.0001

typedef struct {
    int width, height;
    ImgPixel* pix;
} Img;

typedef struct {
  int width, height;
  FloatImgPixel* pix;
} FloatImg;

/*
 * constructors and destructors
 */
Img* Img_New(char* tkPhotoName);
Img* Img_NewBlank(int width, int height);
void Img_Delete(Img* image);

FloatImg* FloatImg_NewBlank(int width, int height);
void FloatImg_Delete(FloatImg *image);

/*
 * copies the Tk photo into our image, allocating or
 * freeing memory if necessary.  So, the value of
 * image->pix isn't guaranteed to be the same.
 *
 * returns 0 on success, or -1 on failure
 */
int Img_GetTk(Img* image, char* tkPhotoName);

/*
 * copies our image to the Tk photo
 *
 * returns 0 on success, or -1 on failure
 */
int Img_PutTk(const Img* image, char* tkPhotoName);

/*
 * makes an image have one color
 */
void Img_SetColor(const Img* image, int red, int green, int blue);

/***************************************************************************
 * Procedures for Tcl bindings
 ***************************************************************************/
 
int Img_Init(Tcl_Interp*);
int Img_RandomNoiseFrom(Img*);
Img* Img_RandomNoiseTo(double value);
int Img_GammaFrom(Img*);
Img* Img_GammaTo(double value);
int Img_SaturationFrom(Img*);
Img* Img_SaturationTo(double value);
int Img_ContrastFrom(Img*);
Img* Img_ContrastTo(double value);
int Img_BrightnessFrom(Img*);
Img* Img_BrightnessTo(double value);
int Img_SharpenFrom(Img*);
Img* Img_SharpenTo(double value);
int Img_Fun1From(Img*);
Img* Img_Fun1To(char * value);

int Img_QuantizationFrom(Img*);
Img* Img_QuantizationTo(char* value);
int Img_DitherFrom(Img*);
Img* Img_DitherTo(char* value);

int clamp(double x);



#endif /* __TKENHANCE_IMG_H__ */
