/*
 * imgNoise.c
 * Dan Wallach <dwallach@cs.princeton.edu>
 * 26 September 1995
 *
 * $Id: imgNoise.c,v 1.1 1995/09/27 09:23:01 dwallach Exp $
 */
 
#include <math.h>
#include "img.h"

static Img* imgSource = NULL;
static Img* imgRandom = NULL;
static Img* imgResult = NULL;

int
Img_RandomNoiseFrom(Img* src) {
    register int i, stop, randomBits;
    
    if(imgSource != NULL) Img_Delete(imgSource);
    imgSource = src;
    
    if(imgResult != NULL && (imgResult->width != src->width || imgResult->height != src->height)) {
        Img_Delete(imgResult);
	imgResult = NULL;
    }
    
    if(imgRandom != NULL && (imgRandom->width != src->width || imgRandom->height != src->height)) {
        Img_Delete(imgRandom);
	imgRandom = NULL;
    }
    
    
    if(imgRandom == NULL) {
	imgRandom = Img_NewBlank(src->width, src->height);
	if(imgRandom == NULL) return -1;
    }
    
    stop=src->width * src->height;
    for(i=0; i<stop; i++) {
	randomBits = random();
        imgRandom->pix[i].r = randomBits & 0xff;
        imgRandom->pix[i].g = (randomBits & 0xff00) >> 8;
        imgRandom->pix[i].b = (randomBits & 0xff0000) >> 16;
    }
    
    return 0;
}

Img*
Img_RandomNoiseTo(double value) {
    register int i, stop;
    register int srcMult, ranMult;
    register ImgPixel* srcPix;
    register ImgPixel* ranPix;
    register ImgPixel* resultPix;
    
    if(imgResult == NULL) {
        imgResult = Img_NewBlank(imgSource->width, imgSource->height);
	if(imgResult == NULL) return NULL;
    }
    
    stop = imgSource->width * imgSource->height;
    srcMult = (int) floor((1.0 - value)*256.0);
    ranMult = (int) floor(value*256.0);
    srcPix = imgSource->pix;
    ranPix = imgRandom->pix;
    resultPix = imgResult->pix;
    
    for(i=0; i<stop; i++) {
        resultPix[i].r =
	    clamp((srcPix[i].r * srcMult +
		   ranPix[i].r * ranMult) >> 8);
	/* clamp down to [0..1] */
        resultPix[i].g =
	    clamp((srcPix[i].g * srcMult +
		   ranPix[i].g * ranMult) >> 8);
        resultPix[i].b =
	    clamp((srcPix[i].b * srcMult +
		   ranPix[i].b * ranMult) >> 8);
    }
    
    return imgResult;
}
